@@ -2,53 +2,34 @@ package Egg::Plugin::Filter::Plugin::Japanese::EUC;
 #
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: EUC.pm 96 2007-05-07 21:31:53Z lushe $
+# $Id: EUC.pm 309 2008-03-30 21:06:49Z lushe $
 #
-
-=head1 NAME
-
-Egg::Plugin::Filter::Plugin::Japanese::EUC - The filter for the Japanese sentence character code is added.
-
-=head1 SYNOPSIS
-
-  use Egg qw/ Filter /;
-  
-  __PACKAGE__->egg_startup(
-  
-    plugin_filter=> {
-      plugin=> [qw/ Japanese::EUC /],
-      },
-  
-    );
-
-  $e->filter(
-    myname   => [qw/ h2z j_strip_j j_trim /],
-    nickname => [qw/ h2z j_strip j_trim /],
-    address  => [qw/ h2z j_hold /],
-    );
-
-=head1 DESCRIPTION
-
-It is a plug-in for the filter that can treat Japanese EUC character-code.
-
-Please refer to the document of L<Egg::Plugin::Filter::Plugin::Japanese>.
-
-=cut
 use strict;
 use warnings;
-use base qw/Egg::Plugin::Filter::Plugin::Japanese/;
+use base qw/ Egg::Plugin::Filter::Plugin::Japanese /;
 use Jcode;
 
-our $VERSION= '2.00';
+our $VERSION= '3.00';
 
 $Egg::Plugin::Filter::Plugin::Japanese::Zspace  = q{(?:\xA1\xA1)};
 $Egg::Plugin::Filter::Plugin::Japanese::RZspace = '';
 
+1;
+
+__END__
+
+=head1 NAME
+
+Egg::Plugin::Filter::Plugin::Japanese::EUC - The filter for the EUC character is set up.
+
+=head1 DESCRIPTION
+
+It sets it up so that the EUC character is treated with L<Egg::Plugin::Filter::Plugin::Japanese>.
+
 =head1 SEE ALSO
 
-L<Egg::Plugin::Filter>,
-L<Egg::Plugin::Filter::Plugin::Japanese>,
 L<Egg::Release>,
+L<Egg::Plugin::Filter::Plugin::Japanese>,
 
 =head1 AUTHOR
 
@@ -64,4 +45,3 @@ at your option, any later version of Perl 5 you may have available.
 
 =cut
 
-1;
