@@ -2,13 +2,19 @@ package Egg::Plugin::HTTP::BrowserDetect;
 #
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id$
+# $Id: BrowserDetect.pm 226 2008-01-27 10:23:16Z lushe $
 #
 use strict;
 use warnings;
 use HTTP::BrowserDetect;
 
-our $VERSION = '2.00';
+our $VERSION = '3.00';
+
+sub browser { shift->{plugin_browser} ||= HTTP::BrowserDetect->new(@_) }
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -17,7 +23,7 @@ Egg::Plugin::HTTP::BrowserDetect - Plugin for HTTP::BrowserDetect.
 =head1 SYNOPSIS
 
   use Egg qw/ HTTP::BrowserDetect /;
-
+  
   if ($e->browser->windows) {
      # OS is Windows.
   } elsif ($e->browser->mac) {
@@ -30,7 +36,7 @@ Egg::Plugin::HTTP::BrowserDetect - Plugin for HTTP::BrowserDetect.
 
 =head1 DESCRIPTION
 
-It is a plug-in to obtain browser information on connected client.
+Information on a browser etc. that the client uses is examined.
 
 see L<HTTP::BrowserDetect>.
 
@@ -38,18 +44,11 @@ see L<HTTP::BrowserDetect>.
 
 =head2 browser ([USER_AGENT])
 
-The object of HTTP::BrowserDetect is returned.
+The object of L<HTTP::BrowserDetect> is returned.
 
-There is usually no [USER_AGENT] needing.
-HTTP::BrowserDetect acquires it from the environment variable.
+It is not necessary usually though USER_AGENT can be passed to the argument.
 
-=cut
-
-sub browser { shift->{browser} ||= HTTP::BrowserDetect->new(@_) }
-
-1;
-
-__END__
+  my $browser= $e->browser;
 
 =head1 SEE ALSO
 
@@ -69,3 +68,4 @@ it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
+
